@@ -1,3 +1,5 @@
+import copy
+
 class JciHitachiStatus:
     idx = {}
 
@@ -1529,3 +1531,177 @@ class JciHitachiHESupport(JciHitachiStatusSupport):
 
     def __init__(self, status, default=0):
         super().__init__(status, default)
+
+
+
+class JciHitachiAWSStatus:
+    compability_mapping = {
+        "AC": {
+            'DeviceType': None,
+            'Switch': 'power',
+            'Mode': 'mode',
+            'FanSpeed': 'air_speed',
+            'TemperatureSetting': 'target_temp',
+            'IndoorTemperature': 'indoor_temp',
+            'OutdoorTemperature': 'outdoor_temp',
+            'SleepModeRemainingTime': 'sleep_timer',
+            'VerticalWindDirectionSwitch': 'vertical_wind_swingable', 
+            'VerticalWindDirectionSetting': 'vertical_wind_direction',
+            'HorizontalWindDirectionSetting': 'horizontal_wind_direction',
+            'MildewProof': 'mold_prev',
+            'QuickMode': 'fast_op',
+            'PowerSaving': 'energy_save',
+            'ControlTone': 'sound_prompt',
+            'PowerConsumption': 'power_kwh',
+            'TaiseiaError': None,
+            'FilterElapsedHour': None,
+            'CleanSwitch': None,
+            'CleanNotification': None,
+            'CleanStatus': None,
+            'Error': None,
+        },
+        "DH": {
+            'DeviceType': None,
+            'Switch': 'power',
+            'Mode': 'mode',
+            'FanSpeed': 'air_speed',
+            'MildewProof': 'mold_prev',
+            'ControlTone': 'sound_control',
+            'SaaControlTone': None,
+            'PowerConsumption': 'power_kwh',
+            'Ion': None,
+            'HumiditySetting': 'target_humidity',
+            'AutoWindDirection': 'wind_swingable',
+            'KeypadLock': None,
+            'DisplayBrightness': 'display_brightness',
+            'FilterControl': 'air_cleaning_filter',
+            'PM25': 'pm25_value',
+            'IndoorHumidity': 'indoor_humidity',
+            'SideAirOutlet': 'side_vent',
+            'Defrost': None,
+            'SmellIndex': 'odor_level',
+            'CleanFilterNotification': 'clean_filter_notify',
+            'TankFullNotification': 'water_full_warning',
+            'TaiseiaError': None,
+            'Error': 'error_code',
+        }
+    }
+    device_type_mapping = {
+        1: "AC",
+        2: "DH",
+        3: "HE",
+        4: "PM25_PANEL",
+    }
+
+    def __init__(self, status: dict) -> None:
+        self._status: dict = self._preprocess(status)
+
+    def __getattr__(self, item):
+        print(item)
+        return self._status[item]
+    
+    def __repr__(self) -> str:
+        return str(self._status)
+
+    def _preprocess(self, status):
+        # device type
+        if status.get("DeviceType"):
+            status["DeviceType"] = self.device_type_mapping[status["DeviceType"]]
+        
+        if not status.get("OutdoorTemperature"):
+            status["OutdoorTemperature"] = 0
+        
+        return status
+
+    @property
+    def status(self):
+        """All status.
+
+        Returns
+        -------
+        dict
+            All status.
+        """
+
+        return self._status
+    
+    @property
+    def legacy_status_class(self):
+        """All legacy status used by the old API.
+
+        Returns
+        -------
+        JciHitachiStatus
+            status.
+        """
+
+        class mock_idx(dict):
+            def __getitem__(self, key):
+                return key
+
+        mapped_status = {self.compability_mapping[self._status["DeviceType"]].get(key): value for key, value in self._status.items()}
+
+        if self._status["DeviceType"] == "AC":
+            if None in mapped_status:
+                del mapped_status[None]
+            ac = JciHitachiAC(mapped_status)
+            ac.idx = mock_idx(ac.idx)
+            return ac
+        elif self._status["DeviceType"] == "DH":
+            if None in mapped_status:
+                del mapped_status[None]
+            dh = JciHitachiDH(mapped_status)
+            dh.idx = mock_idx(dh.idx)
+            return dh
+        return None
+
+    @staticmethod
+    def convert_old_to_new(device_type, old_status_name):
+        for key, value in __class__.compability_mapping[device_type].items():
+            if value == old_status_name:
+                return key
+        return None
+
+class JciHitachiAWSStatusSupport:
+    extended_mapping = {
+        "FirmwareId": None,
+        "Model": "model",
+        "Brand": "brand",
+        "FindMe": None,
+    }
+
+    compability_mapping = copy.deepcopy(JciHitachiAWSStatus.compability_mapping).update(extended_mapping)
+    device_type_mapping = JciHitachiAWSStatus.device_type_mapping
+
+    def __init__(self, status: dict) -> None:
+        self._status: dict = self._preprocess(status)
+
+    def __getattr__(self, item):
+        return self._status[item]
+    
+    def __repr__(self) -> str:
+        return str(self._status)
+
+    def _preprocess(self, status):
+        # device type
+        if status.get("DeviceType"):
+            status["DeviceType"] = self.device_type_mapping[status["DeviceType"]]
+        
+        if not status.get("OutdoorTemperature"):
+            status["OutdoorTemperature"] = 0
+        
+        status["Brand"] = "HITACHI"
+        
+        return status
+
+    @property
+    def status(self):
+        """All status.
+
+        Returns
+        -------
+        dict
+            All status.
+        """
+
+        return self._status
\ No newline at end of file
